@@ -192,7 +192,7 @@ class VirtualsToolsEndpoint(RestEndpoint):
                     )
 
                     dest_virtual.set_effect(effect)
-                except (ValueError, RuntimeError) as msg:
+                except (ValueError, RuntimeError):
                     continue
 
                 dest_virtual.update_effect_config(effect)
