@@ -1,7 +1,6 @@
 import asyncio
 import logging
 import os
-import sys
 import time
 import warnings
 import webbrowser
@@ -106,24 +105,29 @@ class LedFxCore:
         self.ci_testing = ci_testing
         self.generate_typescript_types = generate_typescript_types
         self.offline_mode = offline_mode
-        if sys.platform == "win32":
-            self.loop = asyncio.ProactorEventLoop()
-        else:
+
+        try:
+            import uvloop
+
+            self.loop = uvloop.new_event_loop()
+            _LOGGER.info("Using uvloop for asyncio loop")
+        except ImportError:
             try:
-                import uvloop
+                import winloop
 
-                self.loop = uvloop.new_event_loop()
-                _LOGGER.info("Using uvloop for asyncio loop")
-            except ImportError as error:
-                self.loop = asyncio.get_event_loop()
-                _LOGGER.info("Reverting to asyncio loop")
-        asyncio.set_event_loop(self.loop)
-
-        # self.loop.set_debug(True)
+                self.loop = winloop.new_event_loop()
+                _LOGGER.info("Using winloop for asyncio loop")
+            except ImportError:
+                self.loop = asyncio.new_event_loop()
+                _LOGGER.info("Using standard asyncio loop")
 
         self.thread_executor = ThreadPoolExecutor()
         self.loop.set_default_executor(self.thread_executor)
         self.loop.set_exception_handler(self.loop_exception_handler)
+        asyncio.set_event_loop(self.loop)
+
+        if self.config.get("debug_asyncio", False):
+            self.loop.set_debug(True)
 
         if self.icon:
             self.setup_icon_menu()
@@ -243,13 +247,15 @@ class LedFxCore:
             virtual = self.virtuals.get(vis_id)
             # protect against deleted virtuals
             if virtual:
-                rows = virtual.rows
+                # protect against rows = 0
+                rows = max(1, virtual.rows)
             else:
                 rows = 1
 
             pixels = event.pixels
             pixels_len = len(pixels)
             shape = (rows, int(pixels_len / rows))
+
             if pixels_len > max_len:
                 new_shape, pixels_len = shape_to_fit_len(
                     max_len, shape, pixels_len
