@@ -621,8 +621,11 @@ class Devices(RegistryLoader):
                     config=device["config"],
                     ledfx=self._ledfx,
                 )
-            except vol.MultipleInvalid as e:
-                _LOGGER.exception(e)
+            except Exception as e:
+                # be very prolific on ignoring devices if they are bad
+                _LOGGER.warning(
+                    f"Failed to load device {device.get('id', 'unknown')}: {e}"
+                )
 
     def deactivate_devices(self):
         for device in self.values():
@@ -834,6 +837,7 @@ class Devices(RegistryLoader):
             self.is_universe_separated,
             self.is_openrgb_id_separated,
             self.is_osc_port_path_separated,
+            self.is_ddp_destination_separated,
             self.is_general_port_separated,
         ]:
             yield test(new_type, new_config, pre_device)
@@ -903,6 +907,21 @@ class Devices(RegistryLoader):
             return True
         return False
 
+    def is_ddp_destination_separated(self, new_type, new_config, pre_device):
+        """
+        Check if the new device is DDP destination_id separated from the pre-existing device
+        """
+        if new_type == "ddp" and pre_device.type == "ddp":
+            if new_config["port"] == pre_device.config["port"]:
+                if new_config.get(
+                    "destination_id", 1
+                ) == pre_device.config.get("destination_id", 1):
+                    msg = f"Ignoring {new_config['ip_address']}: Shares IP, port {new_config['port']} and destination_id with existing device {pre_device.name}"
+                    _LOGGER.info(msg)
+                    raise ValueError(msg)
+            return True
+        return False
+
     def is_general_port_separated(self, new_type, new_config, pre_device):
         """
         Check if the new device is port separated from the pre-existing device
