@@ -25,7 +25,7 @@ MAX_MIDI = 108
 
 
 class AudioInputSource:
-    _is_activated = False
+    _audio_stream_active = False
     _audio = None
     _stream = None
     _callbacks = []
@@ -35,6 +35,7 @@ class AudioInputSource:
     _volume_filter = ExpFilter(-90, alpha_decay=0.99, alpha_rise=0.99)
     _subscriber_threshold = 0
     _timer = None
+    _last_active = None
 
     @staticmethod
     def device_index_validator(val):
@@ -69,40 +70,52 @@ class AudioInputSource:
             integer: the sounddevice device index to use for audio input
         """
         device_list = sd.query_devices()
-        default_output_device = sd.default.device["output"]
-        # target device should be the name of the default_output device plus " [Loopback]"
-        target_device = (
-            f"{device_list[default_output_device]['name']} [Loopback]"
-        )
-        # We need to run over the device list looking for the target device
-        # NOTE: Some sound drivers truncate the device name, so we may not find a match
-        for device_index, device in enumerate(device_list):
-            if device["name"] == target_device:
-                # Return the loopback device index
-                _LOGGER.debug(
-                    f"Default audio loopback device found: {device['name']}"
-                )
-                return device_index
-        # If we don't match a Loopback device matching output found - return the default input device index
+        default_output_device_idx = sd.default.device["output"]
         default_input_device_idx = sd.default.device["input"]
-        # The default input device index is not always valid (i.e no default input devices)
-        if default_input_device_idx in AudioInputSource.valid_device_indexes():
-            _LOGGER.debug(
-                "No default audio loopback device found. Using default input device."
-            )
-            return default_input_device_idx
+        if len(device_list) == 0 or default_output_device_idx == -1:
+            _LOGGER.warning("No audio output devices found.")
         else:
-            # Return the first valid input device index if we can't find a valid default input device
-            if len(AudioInputSource.valid_device_indexes()) > 0:
+            default_output_device_name = device_list[
+                default_output_device_idx
+            ]["name"]
+
+            # We need to run over the device list looking for the target devices name
+            _LOGGER.debug(
+                f"Looking for audio loopback device for default output device at index {default_output_device_idx}: {default_output_device_name}"
+            )
+            for device_index, device in enumerate(device_list):
+                # sometimes the audio device name string is truncated, so we need to match what we have and Loopback but otherwise be sloppy
+                if (
+                    default_output_device_name in device["name"]
+                    and "[Loopback]" in device["name"]
+                ):
+                    # Return the loopback device index
+                    _LOGGER.debug(
+                        f"Found audio loopback device for default output device at index {device_index}: {device['name']}"
+                    )
+                    return device_index
+
+        # The default input device index is not always valid (i.e no default input devices)
+        valid_device_indexes = AudioInputSource.valid_device_indexes()
+        if len(valid_device_indexes) == 0:
+            _LOGGER.warning(
+                "No valid audio input devices found. Unable to use audio reactive effects."
+            )
+            return None
+        else:
+            if default_input_device_idx in valid_device_indexes:
                 _LOGGER.debug(
-                    "No valid default audio input device found. Using first valid input device."
+                    f"No audio loopback device found for default output device. Using default input device at index {default_input_device_idx}: {device_list[default_input_device_idx]['name']}"
                 )
-                return next(iter(AudioInputSource.valid_device_indexes()))
+                return default_input_device_idx
             else:
-                _LOGGER.warning(
-                    "No valid audio input devices found. Unable to use audio reactive effects."
-                )
-                return None
+                # Return the first valid input device index if we can't find a valid default input device
+                if len(valid_device_indexes) > 0:
+                    first_valid_idx = next(iter(valid_device_indexes))
+                    _LOGGER.debug(
+                        f"No valid default audio input device found. Using first valid input device at index {first_valid_idx}: {device_list[first_valid_idx]['name']}"
+                    )
+                    return first_valid_idx
 
     @staticmethod
     def query_hostapis():
@@ -137,17 +150,15 @@ class AudioInputSource:
     @property
     def AUDIO_CONFIG_SCHEMA():
         default_device_index = AudioInputSource.default_device_index()
-        valid_device_indexes = AudioInputSource.valid_device_indexes()
-        input_devices = AudioInputSource.input_devices()
-        melbanks = Melbanks.CONFIG_SCHEMA
-        audio_analysis = AudioAnalysisSource.CONFIG_SCHEMA
+        AudioInputSource.valid_device_indexes()
+        AudioInputSource.input_devices()
         return vol.Schema(
             {
                 vol.Optional("sample_rate", default=60): int,
                 vol.Optional("mic_rate", default=44100): int,
                 vol.Optional("fft_size", default=FFT_SIZE): int,
                 vol.Optional("min_volume", default=0.2): vol.All(
-                    vol.Coerce(float), vol.Range(min=0.0, max=10.0)
+                    vol.Coerce(float), vol.Range(min=0.0, max=1.0)
                 ),
                 vol.Optional(
                     "audio_device", default=default_device_index
@@ -164,6 +175,8 @@ class AudioInputSource:
     def __init__(self, ledfx, config):
         self._ledfx = ledfx
         self.lock = threading.Lock()
+        # We must not inherit legacy _callbacks from prior instances
+        self._callbacks = []
         self.update_config(config)
 
         def shutdown_event(e):
@@ -177,24 +190,28 @@ class AudioInputSource:
 
     def update_config(self, config):
         """Deactivate the audio, update the config, the reactivate"""
-        old_input_device = False
-        if hasattr(self, "_config"):
-            old_input_device = self._config["audio_device"]
-
-        if self._is_activated:
+        if self._audio_stream_active:
             self.deactivate()
         self._config = self.AUDIO_CONFIG_SCHEMA.fget()(config)
+
+        # cache up last active and lets see if it changes
+        # Read _last_active with lock protection
+        with self.lock:
+            last_active = self._last_active
+
+        # Activate outside the lock to avoid deadlock
         if len(self._callbacks) != 0:
             self.activate()
-        if (
-            old_input_device
-            and self._config["audio_device"] is not old_input_device
-        ):
-            self._ledfx.events.fire_event(
-                AudioDeviceChangeEvent(
-                    self.input_devices()[self._config["audio_device"]]
+
+        # Check if device changed and fire event if needed
+        with self.lock:
+            if last_active != self._last_active:
+                self._ledfx.events.fire_event(
+                    AudioDeviceChangeEvent(
+                        self.input_devices()[self._config["audio_device"]]
+                    )
                 )
-            )
+
         self._ledfx.config["audio"] = self._config
 
     def activate(self):
@@ -208,6 +225,7 @@ class AudioInputSource:
         # Enumerate all of the input devices and find the one matching the
         # configured host api and device name
         input_devices = self.query_devices()
+
         hostapis = self.query_hostapis()
         default_device = self.default_device_index()
         if default_device is None:
@@ -220,17 +238,30 @@ class AudioInputSource:
             self.deactivate()
             return
         valid_device_indexes = self.valid_device_indexes()
+        _LOGGER.debug("********************************************")
+        _LOGGER.debug("Valid audio input devices:")
+        for index in valid_device_indexes:
+            hostapi_name = hostapis[input_devices[index]["hostapi"]]["name"]
+            device_name = input_devices[index]["name"]
+            input_channels = input_devices[index]["max_input_channels"]
+            _LOGGER.debug(
+                f"Audio Device {index}\t{hostapi_name}\t{device_name}\tinput_channels: {input_channels}"
+            )
+        _LOGGER.debug("********************************************")
         device_idx = self._config["audio_device"]
+        _LOGGER.debug(
+            f"default_device: {default_device} config_device: {device_idx}"
+        )
 
         if device_idx > max(valid_device_indexes):
             _LOGGER.warning(
-                f"Invalid audio device index: {device_idx}. Reverting to default input device."
+                f"Audio device out of range: {device_idx}. Reverting to default input device: {default_device}"
             )
             device_idx = default_device
 
         elif device_idx not in valid_device_indexes:
             _LOGGER.warning(
-                f"Audio device {input_devices[device_idx]['name']} has no input channels. Reverting to default input device."
+                f"Audio device {input_devices[device_idx]['name']} not in valid_device_indexes. Reverting to default input device: {default_device}"
             )
             device_idx = default_device
 
@@ -283,11 +314,33 @@ class AudioInputSource:
             self.delay_queue = None
 
         def open_audio_stream(device_idx):
+            """
+            Opens an audio stream for the specified input device.
+            Parameters:
+            device_idx (int): The index of the input device to open the audio stream for.
+            Behavior:
+            - Detects if the device is a Windows WASAPI Loopback device and logs its name and channel count.
+            - If the device is a WEB AUDIO device, initializes a WebAudioStream and sets it as the active audio stream.
+            - For other devices, initializes an InputStream with the device's default sample rate and other parameters.
+            - Initializes a resampler with the "sinc_fastest" algorithm that downmixes the source to a single-channel.
+            - Logs the name of the opened audio source.
+            - Starts the audio stream and sets the audio stream active flag to True.
+            """
+
             device = input_devices[device_idx]
-            ch = 1
-            if hostapis[device["hostapi"]]["name"] == "Windows WASAPI":
-                if "Loopback" in device["name"]:
-                    ch = 2
+            channels = None
+            if (
+                hostapis[device["hostapi"]]["name"] == "Windows WASAPI"
+                and "Loopback" in device["name"]
+            ):
+                _LOGGER.info(
+                    f"Loopback device detected: {device['name']} with {device['max_input_channels']} channels"
+                )
+            else:
+                # if are not a windows loopback device, we will downmix to mono
+                # issue seen with poor audio behaviour on Mac and Linux
+                # this is similar to the long standing prior implementation
+                channels = 1
 
             if hostapis[device["hostapi"]]["name"] == "WEB AUDIO":
                 ledfx.api.websocket.ACTIVE_AUDIO_STREAM = self._stream = (
@@ -299,7 +352,6 @@ class AudioInputSource:
                 self._stream = self._audio.InputStream(
                     samplerate=int(device["default_samplerate"]),
                     device=device_idx,
-                    channels=ch,
                     callback=self._audio_sample_callback,
                     dtype=np.float32,
                     latency="low",
@@ -307,6 +359,8 @@ class AudioInputSource:
                         device["default_samplerate"]
                         / self._config["sample_rate"]
                     ),
+                    # only pass channels if we set it to something other than None
+                    **({"channels": channels} if channels is not None else {}),
                 )
 
             self.resampler = samplerate.Resampler("sinc_fastest", channels=1)
@@ -316,10 +370,13 @@ class AudioInputSource:
             )
 
             self._stream.start()
+            self._audio_stream_active = True
 
         try:
             open_audio_stream(device_idx)
-            self._is_activated = True
+            # Protect concurrent access to _last_active with lock
+            with self.lock:
+                self._last_active = device_idx
         except OSError as e:
             _LOGGER.critical(
                 f"Unable to open Audio Device: {e} - please retry."
@@ -330,18 +387,26 @@ class AudioInputSource:
             open_audio_stream(default_device)
 
     def deactivate(self):
+        # Stop the stream outside the lock to avoid deadlock with audio callback
+        # The audio callback thread may be waiting to complete, and if it needs
+        # any locks, holding self.lock while calling stop() creates a circular wait
+        stream_to_close = None
         with self.lock:
             if self._stream:
-                self._stream.stop()
-                self._stream.close()
+                stream_to_close = self._stream
                 self._stream = None
-            self._is_activated = False
-        _LOGGER.info("Audio source closed.")
+            self._audio_stream_active = False
+
+        # Stop/close outside the lock
+        if stream_to_close:
+            stream_to_close.stop()
+            stream_to_close.close()
+            _LOGGER.info("Audio source closed.")
 
     def subscribe(self, callback):
         """Registers a callback with the input source"""
         self._callbacks.append(callback)
-        if len(self._callbacks) > 0 and not self._is_activated:
+        if len(self._callbacks) > 0 and not self._audio_stream_active:
             self.activate()
         if self._timer is not None:
             self._timer.cancel()
@@ -353,7 +418,7 @@ class AudioInputSource:
             self._callbacks.remove(callback)
         if (
             len(self._callbacks) <= self._subscriber_threshold
-            and self._is_activated
+            and self._audio_stream_active
         ):
             if self._timer is not None:
                 self._timer.cancel()
@@ -366,7 +431,7 @@ class AudioInputSource:
         self._timer = None
         if (
             len(self._callbacks) <= self._subscriber_threshold
-            and self._is_activated
+            and self._audio_stream_active
         ):
             self.deactivate()
 
@@ -798,9 +863,8 @@ class AudioAnalysisSource(AudioInputSource):
             oscillator = (
                 1 - (self.beat_period - time_since_beat) / self.beat_period
             ) + self.beat_counter
-            # ensure it's between 0 and 1. useful when audio cuts
-            oscillator = min(4, oscillator)
-            oscillator = max(0, oscillator)
+            # ensure it's between [0 and 4). useful when audio cuts
+            oscillator = oscillator % 4
         return oscillator
 
     def beat_oscillator(self):
