@@ -21,8 +21,11 @@ _LOGGER = logging.getLogger(__name__)
 class Keybeat2d(Twod, GifBase):
     NAME = "Keybeat2d"
     CATEGORY = "Matrix"
+    # background colors make no sense with gifs, just hide them
     HIDDEN_KEYS = Twod.HIDDEN_KEYS + [
         "background_color",
+        "background_brightness",
+        "background_mode",
     ]
     ADVANCED_KEYS = Twod.ADVANCED_KEYS + [
         "deep_diag",
@@ -303,10 +306,6 @@ class Keybeat2d(Twod, GifBase):
         self.num_beat_frames = len(self.beat_frames)
         self.last_beat = 0.0
 
-        if self.rotate == 1 or self.rotate == 3:
-            self.stretch_v, self.stretch_h = self.stretch_h, self.stretch_v
-            self.center_v, self.center_h = self.center_h, self.center_v
-
         self.suppress_beat = False
         self.min_vol_found_in_last_beat = False
         self.above_min_vol = False
@@ -315,6 +314,10 @@ class Keybeat2d(Twod, GifBase):
         super().do_once()
         # defer things that can't be done when pixel_count is not known
 
+        if self.rotate == 1 or self.rotate == 3:
+            self.stretch_v, self.stretch_h = self.stretch_h, self.stretch_v
+            self.center_v, self.center_h = self.center_h, self.center_v
+
         for frame in self.post_frames:
             if not self.force_fit:
                 stretch_height = int(self.stretch_v * frame.height)
